Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/distrib/utils/sysinst Add support for installing source sets...



details:   https://anonhg.NetBSD.org/src/rev/106d61f35abe
branches:  trunk
changeset: 772659:106d61f35abe
user:      gson <gson%NetBSD.org@localhost>
date:      Tue Jan 10 21:02:47 2012 +0000

description:
Add support for installing source sets as discussed on tech-install,
with improved German translations from Martin Husemann and Julian
Djamil Fagir.  French, Spanish, and Polish translations are
still needed.  OK christos, riz.

diffstat:

 distrib/utils/sysinst/defs.h    |  29 +++++++++++++++++---
 distrib/utils/sysinst/main.c    |   8 +++--
 distrib/utils/sysinst/menus.mi  |  32 +++++++++++++++--------
 distrib/utils/sysinst/msg.mi.de |  23 +++++++++++++++-
 distrib/utils/sysinst/msg.mi.en |  23 +++++++++++++++-
 distrib/utils/sysinst/msg.mi.es |  23 +++++++++++++++-
 distrib/utils/sysinst/msg.mi.fr |  23 +++++++++++++++-
 distrib/utils/sysinst/msg.mi.pl |  23 +++++++++++++++-
 distrib/utils/sysinst/net.c     |  19 ++++++++-----
 distrib/utils/sysinst/util.c    |  55 ++++++++++++++++++++++++++++++++--------
 10 files changed, 210 insertions(+), 48 deletions(-)

diffs (truncated from 574 to 300 lines):

diff -r 630f1dfd9088 -r 106d61f35abe distrib/utils/sysinst/main.c
--- a/distrib/utils/sysinst/main.c      Tue Jan 10 20:47:01 2012 +0000
+++ b/distrib/utils/sysinst/main.c      Tue Jan 10 21:02:47 2012 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: main.c,v 1.62 2012/01/05 21:29:24 christos Exp $       */
+/*     $NetBSD: main.c,v 1.63 2012/01/10 21:02:47 gson Exp $   */
 
 /*
  * Copyright 1997 Piermont Information Systems Inc.
@@ -80,10 +80,12 @@
        {"release", REL, rel, sizeof rel},
        {"machine", MACH, machine, sizeof machine},
        {"xfer dir", "/usr/INSTALL", xfer_dir, sizeof xfer_dir},
-       {"ext dir", "", ext_dir, sizeof ext_dir},
+       {"ext dir", "", ext_dir_bin, sizeof ext_dir_bin},
+       {"ext src dir", "", ext_dir_src, sizeof ext_dir_src},
        {"ftp host", SYSINST_FTP_HOST, ftp.host, sizeof ftp.host},
        {"ftp dir", SYSINST_FTP_DIR, ftp.dir, sizeof ftp.dir},
-       {"ftp prefix", "/" MACH "/binary/sets", set_dir, sizeof set_dir},
+       {"ftp prefix", "/" MACH "/binary/sets", set_dir_bin, sizeof set_dir_bin},
+       {"ftp src prefix", "/source/sets", set_dir_src, sizeof set_dir_src},
        {"ftp user", "ftp", ftp.user, sizeof ftp.user},
        {"ftp pass", "", ftp.pass, sizeof ftp.pass},
        {"ftp proxy", "", ftp.proxy, sizeof ftp.proxy},
diff -r 630f1dfd9088 -r 106d61f35abe distrib/utils/sysinst/menus.mi
--- a/distrib/utils/sysinst/menus.mi    Tue Jan 10 20:47:01 2012 +0000
+++ b/distrib/utils/sysinst/menus.mi    Tue Jan 10 21:02:47 2012 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: menus.mi,v 1.43 2011/10/30 00:30:56 jakllsch Exp $     */
+/*     $NetBSD: menus.mi,v 1.44 2012/01/10 21:02:47 gson Exp $ */
 
 /*-
  * Copyright (c) 2003 The NetBSD Foundation, Inc.
@@ -246,8 +246,10 @@
                action { src_prompt(MSG_Host, ftp.host, sizeof ftp.host); };
        option {src_legend(menu, MSG_Base_dir, ftp.dir);},
                action { src_prompt(MSG_Base_dir, ftp.dir, sizeof ftp.dir); };
-       option {src_legend(menu, MSG_Set_dir, set_dir);},
-               action { src_prompt(MSG_Set_dir, set_dir, sizeof set_dir); };
+       option {src_legend(menu, MSG_Set_dir_bin, set_dir_bin);},
+               action { src_prompt(MSG_Set_dir_bin, set_dir_bin, sizeof set_dir_bin); };
+       option {src_legend(menu, MSG_Set_dir_src, set_dir_src);},
+               action { src_prompt(MSG_Set_dir_src, set_dir_src, sizeof set_dir_src); };
        option {src_legend(menu, MSG_User, ftp.user);},
                action { src_prompt(MSG_User, ftp.user, sizeof ftp.user);
                        ftp.pass[0] = 0;
@@ -286,8 +288,10 @@
                action { src_prompt(MSG_Host, nfs_host, sizeof nfs_host); };
        option {src_legend(menu, MSG_Base_dir, nfs_dir);},
                action { src_prompt(MSG_Base_dir, nfs_dir, sizeof nfs_dir); };
-       option {src_legend(menu, MSG_Set_dir, set_dir);},
-               action { src_prompt(MSG_Set_dir, set_dir, sizeof set_dir); };
+       option {src_legend(menu, MSG_Set_dir_bin, set_dir_bin);},
+               action { src_prompt(MSG_Set_dir_bin, set_dir_bin, sizeof set_dir_bin); };
+       option {src_legend(menu, MSG_Set_dir_src, set_dir_src);},
+               action { src_prompt(MSG_Set_dir_src, set_dir_src, sizeof set_dir_src); };
 
 menu fdremount, title MSG_What_do_you_want_to_do;
        option MSG_Try_again, exit, action { *(int *)arg = SET_CONTINUE; };
@@ -322,8 +326,10 @@
        display action { msg_display_add(MSG_cdromsource); };
        option {src_legend(menu, MSG_Device, cdrom_dev);},
                action { src_prompt(MSG_dev, cdrom_dev, sizeof cdrom_dev); };
-       option {src_legend(menu, MSG_Set_dir, set_dir);},
-               action { src_prompt(MSG_Set_dir, set_dir, sizeof set_dir); };
+       option {src_legend(menu, MSG_Set_dir_bin, set_dir_bin);},
+               action { src_prompt(MSG_Set_dir_bin, set_dir_bin, sizeof set_dir_bin); };
+       option {src_legend(menu, MSG_Set_dir_src, set_dir_src);},
+               action { src_prompt(MSG_Set_dir_src, set_dir_src, sizeof set_dir_src); };
 
 menu localfssource, y=-4, x=0, w=70, no box, no clear, exitstring MSG_Continue;
        display action { msg_display(MSG_localfssource); };
@@ -333,15 +339,19 @@
                action { src_prompt(MSG_filesys, localfs_fs, sizeof localfs_fs); };
        option {src_legend(menu, MSG_Base_dir, localfs_dir);},
                action { src_prompt(MSG_Base_dir, localfs_dir, sizeof localfs_dir);};
-       option {src_legend(menu, MSG_Set_dir, set_dir);},
-               action { src_prompt(MSG_Set_dir, set_dir, sizeof set_dir); };
+       option {src_legend(menu, MSG_Set_dir_bin, set_dir_bin);},
+               action { src_prompt(MSG_Set_dir_bin, set_dir_bin, sizeof set_dir_bin); };
+       option {src_legend(menu, MSG_Set_dir_src, set_dir_src);},
+               action { src_prompt(MSG_Set_dir_src, set_dir_src, sizeof set_dir_src); };
 
 menu localdirsource, y=-4, x=0, w=70, no box, no clear, exitstring MSG_Continue;
        display action { msg_display(MSG_localdir); };
        option {src_legend(menu, MSG_Base_dir, localfs_dir);},
                action { src_prompt(MSG_Base_dir, localfs_dir, 60); };
-       option {src_legend(menu, MSG_Set_dir, set_dir);},
-               action { src_prompt(MSG_Set_dir, set_dir, 60); };
+       option {src_legend(menu, MSG_Set_dir_bin, set_dir_bin);},
+               action { src_prompt(MSG_Set_dir_bin, set_dir_bin, 60); };
+       option {src_legend(menu, MSG_Set_dir_src, set_dir_src);},
+               action { src_prompt(MSG_Set_dir_src, set_dir_src, 60); };
 
 menu namesrv6, title MSG_Select_IPv6_DNS_server;
        option "google-public-dns-a.google.com", exit, action
diff -r 630f1dfd9088 -r 106d61f35abe distrib/utils/sysinst/msg.mi.de
--- a/distrib/utils/sysinst/msg.mi.de   Tue Jan 10 20:47:01 2012 +0000
+++ b/distrib/utils/sysinst/msg.mi.de   Tue Jan 10 21:02:47 2012 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: msg.mi.de,v 1.60 2012/01/09 01:51:47 riz Exp $ */
+/*     $NetBSD: msg.mi.de,v 1.61 2012/01/10 21:02:47 gson Exp $        */
 
 /*
  * Copyright 1997 Piermont Information Systems Inc.
@@ -829,6 +829,24 @@
 message set_X11_prog
 {X11 Programmierung}
 
+message set_source
+{Quelltexte}
+
+message set_syssrc
+{Kernel Quelltexte}
+
+message set_src
+{Basissystem Quelltexte}
+
+message set_sharesrc
+{Share Quelltexte}
+
+message set_gnusrc
+{GNU Quelltexte}
+
+message set_xsrc
+{X11 Quelltexte}
+
 message cur_distsets_row
 {%-27s %3s}
 
@@ -966,7 +984,8 @@
 message hidden {** versteckt **}
 message Host {Host}
 message Base_dir {Basispfad}
-message Set_dir {Verzeichnis}
+message Set_dir_bin {Binärpaket-Verzeichnis}
+message Set_dir_src {Quelltext-Verzeichnis}
 message Xfer_dir {Zwischenspeicher}
 message User {Benutzer}
 message Password {Passwort}
diff -r 630f1dfd9088 -r 106d61f35abe distrib/utils/sysinst/msg.mi.en
--- a/distrib/utils/sysinst/msg.mi.en   Tue Jan 10 20:47:01 2012 +0000
+++ b/distrib/utils/sysinst/msg.mi.en   Tue Jan 10 21:02:47 2012 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: msg.mi.en,v 1.168 2012/01/09 01:51:47 riz Exp $        */
+/*     $NetBSD: msg.mi.en,v 1.169 2012/01/10 21:02:47 gson Exp $       */
 
 /*
  * Copyright 1997 Piermont Information Systems Inc.
@@ -769,6 +769,24 @@
 message set_X11_prog
 {X11 programming}
 
+message set_source
+{Source sets}
+
+message set_syssrc
+{Kernel sources}
+
+message set_src
+{Base sources}
+
+message set_sharesrc
+{Share sources}
+
+message set_gnusrc
+{GNU sources}
+
+message set_xsrc
+{X11 sources}
+
 message cur_distsets_row
 {%-27s %3s}
 
@@ -906,7 +924,8 @@
 message hidden {** hidden **}
 message Host {Host}
 message Base_dir {Base directory}
-message Set_dir {Set directory}
+message Set_dir_bin {Binary set directory}
+message Set_dir_src {Source set directory}
 message Xfer_dir {Transfer directory}
 message User {User}
 message Password {Password}
diff -r 630f1dfd9088 -r 106d61f35abe distrib/utils/sysinst/msg.mi.es
--- a/distrib/utils/sysinst/msg.mi.es   Tue Jan 10 20:47:01 2012 +0000
+++ b/distrib/utils/sysinst/msg.mi.es   Tue Jan 10 21:02:47 2012 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: msg.mi.es,v 1.38 2012/01/09 01:51:47 riz Exp $ */
+/*     $NetBSD: msg.mi.es,v 1.39 2012/01/10 21:02:47 gson Exp $        */
 
 /*
  * Copyright 1997 Piermont Information Systems Inc.
@@ -792,6 +792,24 @@
 message set_X11_prog
 {Programación de X11}
 
+message set_source
+{Source sets}
+
+message set_syssrc
+{Kernel sources}
+
+message set_src
+{Base sources}
+
+message set_sharesrc
+{Share sources}
+
+message set_gnusrc
+{GNU sources}
+
+message set_xsrc
+{X11 sources}
+
 message cur_distsets_row
 {%-27s %3s}
 
@@ -931,7 +949,8 @@
 message hidden {** oculto **}
 message Host {Máquina}
 message Base_dir {Directorio base}
-message Set_dir {Directorio de conjuntos}
+message Set_dir_src {Directorio de conjuntos binary} /* fix XLAT */
+message Set_dir_bin {Directorio de conjuntos source} /* fix XLAT */
 message Xfer_dir {Directorio a transferir a}
 message User {Usuario}
 message Password {Contraseña}
diff -r 630f1dfd9088 -r 106d61f35abe distrib/utils/sysinst/msg.mi.fr
--- a/distrib/utils/sysinst/msg.mi.fr   Tue Jan 10 20:47:01 2012 +0000
+++ b/distrib/utils/sysinst/msg.mi.fr   Tue Jan 10 21:02:47 2012 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: msg.mi.fr,v 1.118 2012/01/09 01:51:47 riz Exp $        */
+/*     $NetBSD: msg.mi.fr,v 1.119 2012/01/10 21:02:47 gson Exp $       */
 



Home | Main Index | Thread Index | Old Index
diff -r 630f1dfd9088 -r 106d61f35abe distrib/utils/sysinst/defs.h
--- a/distrib/utils/sysinst/defs.h      Tue Jan 10 20:47:01 2012 +0000
+++ b/distrib/utils/sysinst/defs.h      Tue Jan 10 21:02:47 2012 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: defs.h,v 1.160 2012/01/05 22:18:36 christos Exp $      */
+/*     $NetBSD: defs.h,v 1.161 2012/01/10 21:02:47 gson Exp $  */
 
 /*
  * Copyright 1997 Piermont Information Systems Inc.
@@ -122,6 +122,13 @@
     SET_MD_2,          /* Machine dependent set */
     SET_MD_3,          /* Machine dependent set */
     SET_MD_4,          /* Machine dependent set */
+    
+    /* Source sets */
+    SET_SYSSRC,
+    SET_SRC,
+    SET_SHARESRC,
+    SET_GNUSRC,
+    SET_XSRC,
 
     SET_LAST,
     SET_GROUP,         /* Start of submenu */
@@ -144,6 +151,9 @@
 /* All machine dependent sets */
 #define SET_MD SET_MD_1, SET_MD_2, SET_MD_3, SET_MD_4
 
+/* All source sets */
+#define SET_SOURCE SET_SYSSRC, SET_SRC, SET_SHARESRC, SET_GNUSRC, SET_XSRC
+
 /* Set list flags */
 #define SFLAG_MINIMAL  1
 #define        SFLAG_NOX       2
@@ -278,11 +288,17 @@
 #define SYSINST_FTP_DIR                "pub/NetBSD/NetBSD-" REL
 #endif
 
-/* Abs. path we extract from */
-char ext_dir[STRSIZE];
+/* Abs. path we extract binary sets from */
+char ext_dir_bin[STRSIZE];
+
+/* Abs. path we extract source sets from */
+char ext_dir_src[STRSIZE];
 
-/* Place we look in all fs types */
-char set_dir[STRSIZE];
+/* Place we look for binary sets in all fs types */
+char set_dir_bin[STRSIZE];
+
+/* Place we look for source sets in all fs types */
+char set_dir_src[STRSIZE];
 
 struct {
     char host[STRSIZE];
@@ -427,6 +443,9 @@
 void   init_set_status(int);
 void   customise_sets(void);
 void   umount_mnt2(void);
+int    set_is_source(const char *);
+const char *set_dir_for_set(const char *);
+const char *ext_dir_for_set(const char *);
 
 /* from target.c */
 #if defined(DEBUG)  || defined(DEBUG_ROOT)